# SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
# SPDX-FileCopyrightText: Copyright (c) 2021 James Carr for Commedagh
#
# SPDX-License-Identifier: MIT
"""
`commedagh_pypi-version-testing`
================================================================================

testing pypi versioning


* Author(s): James Carr

Implementation Notes
--------------------

**Hardware:**

.. todo:: Add links to any specific hardware product page(s), or category page(s).
  Use unordered list & hyperlink rST inline format: "* `Link Text <url>`_"

**Software and Dependencies:**

* Adafruit CircuitPython firmware for the supported boards:
  https://github.com/adafruit/circuitpython/releases

.. todo:: Uncomment or remove the Bus Device and/or the Register library dependencies
  based on the library's use of either.

# * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
# * Adafruit's Register library: https://github.com/adafruit/Adafruit_CircuitPython_Register
"""

# imports

__version__ = "0.0.1-alpha23"
__repo__ = "https://github.com/lesamouraipourpre/Commedagh_CircuitPython_pypi-version-testing.git"



# SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
# SPDX-FileCopyrightText: Copyright (c) 2021 James Carr for Commedagh
#
# SPDX-License-Identifier: MIT

"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages
import subprocess

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))


__version__ = "0.0.1-alpha23"


# def _get_version_from_git():
#     try:
#         git_out = subprocess.check_output(["git", "describe", "--tags"])
#         version = git_out.strip().decode("utf-8")

#         # Detect a development build and mutate it to be valid semver and valid python version.
#         pieces = version.split("-")
#         if len(pieces) > 2:
#             # Merge the commit portion onto the commit count since the tag.
#             pieces[-2] += "+" + pieces[-1]
#             pieces.pop()
#             # Merge the commit count and build to the pre-release identifier.
#             pieces[-2] += ".dev." + pieces[-1]
#             pieces.pop()
#         version = "-".join(pieces)
#         return version
#     except subprocess.CalledProcessError:
#         # Can't figure a version most likely because there are no tags yet
#         return "0.0.0"


# def _get_version():
#     # Do not use the actual version string or it will get replaced by munging.
#     return (
#         __version__
#         if __version__ != "\x30.\x30.\x30-auto.\x30"
#         else _get_version_from_git()
#     )


# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    # Community Bundle Information
    name="commedagh-circuitpython-pypi-version-testing",
    use_scm_version={
        "git_describe_command": "git describe --tags --long",
        "local_scheme": "no-local-version",
    },
    setup_requires=["setuptools_scm"],
    description="testing pypi versioning",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # The project's main homepage.
    url="https://github.com/lesamouraipourpre/Commedagh_CircuitPython_pypi-version-testing.git",
    # Author details
    author="James Carr",
    author_email="lesamouraipourpre@gmail.com",
    version=__version__,
    install_requires=["Adafruit-Blinka"],
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    # What does your project relate to?
    keywords="adafruit blinka circuitpython micropython pypi-version-testing test pypi "
    "version",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # TODO: IF LIBRARY FILES ARE A PACKAGE FOLDER,
    #       CHANGE `py_modules=['...']` TO `packages=['...']`
    packages=["commedagh_pypi_version_testing"],
)
